@@ -6,7 +6,7 @@ use crate::{
             responses::ReadHealthResponse,
         },
     },
-    client::VaultClient,
+    client::Client,
     error::ClientError,
 };
 
@@ -25,7 +25,7 @@ pub enum ServerStatus {
 /// Returns health information about the Vault server.
 ///
 /// See [ReadHealthRequest]
-pub async fn health(client: &VaultClient) -> Result<ReadHealthResponse, ClientError> {
+pub async fn health(client: &impl Client) -> Result<ReadHealthResponse, ClientError> {
     let endpoint = ReadHealthRequest::builder().build().unwrap();
     api::exec_with_no_result(client, endpoint).await
 }
@@ -33,7 +33,7 @@ pub async fn health(client: &VaultClient) -> Result<ReadHealthResponse, ClientEr
 /// Seals the Vault server.
 ///
 /// See [SealRequest]
-pub async fn seal(client: &VaultClient) -> Result<(), ClientError> {
+pub async fn seal(client: &impl Client) -> Result<(), ClientError> {
     let endpoint = SealRequest::builder().build().unwrap();
     api::exec_with_empty(client, endpoint).await
 }
@@ -41,35 +41,35 @@ pub async fn seal(client: &VaultClient) -> Result<(), ClientError> {
 /// Returns the status of the Vault server.
 ///
 /// See [ReadHealthRequest]
-pub async fn status(client: &VaultClient) -> ServerStatus {
+pub async fn status(client: &impl Client) -> Result<ServerStatus, ClientError> {
     let result = health(client).await;
     match result {
-        Ok(_) => ServerStatus::OK,
-        Err(ref e) => match e {
+        Ok(_) => Ok(ServerStatus::OK),
+        Err(e) => match e {
             ClientError::RestClientError { source } => match source {
                 rustify::errors::ClientError::ServerResponseError {
                     code: 429,
                     content: _,
-                } => ServerStatus::STANDBY,
+                } => Ok(ServerStatus::STANDBY),
                 rustify::errors::ClientError::ServerResponseError {
                     code: 472,
                     content: _,
-                } => ServerStatus::RECOVERY,
+                } => Ok(ServerStatus::RECOVERY),
                 rustify::errors::ClientError::ServerResponseError {
                     code: 473,
                     content: _,
-                } => ServerStatus::PERFSTANDBY,
+                } => Ok(ServerStatus::PERFSTANDBY),
                 rustify::errors::ClientError::ServerResponseError {
                     code: 501,
                     content: _,
-                } => ServerStatus::UNINITIALIZED,
+                } => Ok(ServerStatus::UNINITIALIZED),
                 rustify::errors::ClientError::ServerResponseError {
                     code: 503,
                     content: _,
-                } => ServerStatus::SEALED,
-                _ => ServerStatus::UNKNOWN,
+                } => Ok(ServerStatus::SEALED),
+                _ => Err(ClientError::RestClientError { source }),
             },
-            _ => ServerStatus::UNKNOWN,
+            _ => Err(e),
         },
     }
 }
@@ -82,14 +82,14 @@ pub mod auth {
         EnableAuthRequest, EnableAuthRequestBuilder, ListAuthsRequest,
     };
     use crate::api::sys::responses::AuthResponse;
-    use crate::client::VaultClient;
+    use crate::client::Client;
     use crate::error::ClientError;
 
     /// Enables an auth engine at the given path
     ///
     /// See [EnableAuthRequest]
     pub async fn enable(
-        client: &VaultClient,
+        client: &impl Client,
         path: &str,
         engine_type: &str,
         opts: Option<&mut EnableAuthRequestBuilder>,
@@ -107,7 +107,7 @@ pub mod auth {
     /// Lists all mounted auth engines
     ///
     /// See [ListAuthsRequest]
-    pub async fn list(client: &VaultClient) -> Result<HashMap<String, AuthResponse>, ClientError> {
+    pub async fn list(client: &impl Client) -> Result<HashMap<String, AuthResponse>, ClientError> {
         let endpoint = ListAuthsRequest::builder().build().unwrap();
         api::exec_with_result(client, endpoint).await
     }
@@ -121,14 +121,14 @@ pub mod mount {
         EnableEngineRequest, EnableEngineRequestBuilder, ListMountsRequest,
     };
     use crate::api::sys::responses::MountResponse;
-    use crate::client::VaultClient;
+    use crate::client::Client;
     use crate::error::ClientError;
 
     /// Enables a secret engine at the given path
     ///
     /// See [EnableEngineRequest]
     pub async fn enable(
-        client: &VaultClient,
+        client: &impl Client,
         path: &str,
         engine_type: &str,
         opts: Option<&mut EnableEngineRequestBuilder>,
@@ -146,12 +146,65 @@ pub mod mount {
     /// Lists all mounted secret engines
     ///
     /// See [ListMountsRequest]
-    pub async fn list(client: &VaultClient) -> Result<HashMap<String, MountResponse>, ClientError> {
+    pub async fn list(client: &impl Client) -> Result<HashMap<String, MountResponse>, ClientError> {
         let endpoint = ListMountsRequest::builder().build().unwrap();
         api::exec_with_result(client, endpoint).await
     }
 }
 
+pub mod policy {
+    use crate::{
+        api::{
+            self,
+            sys::{
+                requests::{
+                    CreatePolicyRequest, DeletePolicyRequest, ListPoliciesRequest,
+                    ReadPolicyRequest,
+                },
+                responses::{ListPoliciesResponse, ReadPolicyResponse},
+            },
+        },
+        client::Client,
+        error::ClientError,
+    };
+
+    /// Deletes the given policy.
+    ///
+    /// See [DeletePolicyRequest]
+    pub async fn delete(client: &impl Client, name: &str) -> Result<(), ClientError> {
+        let endpoint = DeletePolicyRequest::builder().name(name).build().unwrap();
+        api::exec_with_empty(client, endpoint).await
+    }
+
+    /// Lists all configured policies.
+    ///
+    /// See [ListPoliciesRequest]
+    pub async fn list(client: &impl Client) -> Result<ListPoliciesResponse, ClientError> {
+        let endpoint = ListPoliciesRequest::builder().build().unwrap();
+        api::exec_with_result(client, endpoint).await
+    }
+
+    /// Reads the given policy.
+    ///
+    /// See [ReadPolicyRequest]
+    pub async fn read(client: &impl Client, name: &str) -> Result<ReadPolicyResponse, ClientError> {
+        let endpoint = ReadPolicyRequest::builder().name(name).build().unwrap();
+        api::exec_with_result(client, endpoint).await
+    }
+
+    /// Sets the given policy.
+    ///
+    /// See [CreatePolicyRequest]
+    pub async fn set(client: &impl Client, name: &str, policy: &str) -> Result<(), ClientError> {
+        let endpoint = CreatePolicyRequest::builder()
+            .name(name)
+            .policy(policy)
+            .build()
+            .unwrap();
+        api::exec_with_empty(client, endpoint).await
+    }
+}
+
 pub mod wrapping {
     use serde::de::DeserializeOwned;
 
@@ -163,7 +216,7 @@ pub mod wrapping {
                 responses::WrappingLookupResponse,
             },
         },
-        client::VaultClient,
+        client::Client,
         error::ClientError,
     };
 
@@ -171,7 +224,7 @@ pub mod wrapping {
     ///
     /// See [WrappingLookupResponse]
     pub async fn lookup(
-        client: &VaultClient,
+        client: &impl Client,
         token: &str,
     ) -> Result<WrappingLookupResponse, ClientError> {
         let endpoint = WrappingLookupRequest::builder()
@@ -185,7 +238,7 @@ pub mod wrapping {
     ///
     /// See [UnwrapRequest]
     pub async fn unwrap<D: DeserializeOwned>(
-        client: &VaultClient,
+        client: &impl Client,
         token: Option<&str>,
     ) -> Result<D, ClientError> {
         let endpoint = UnwrapRequest {
